SettableParser<R> class

A parser that is not defined, but that can be set at a later point in time.

Inheritance
Implemented types
Available extensions

Constructors

SettableParser(Parser<R> delegate)

Properties

children → List<Parser>
The list of directly referenced parsers.
no setterinherited
delegate ↔ Parser<R>
The parser this parser delegates to.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept(String input, {int start = 0}) → bool

Available on Parser<R>, provided by the AcceptParser extension

Tests if the input can be successfully parsed.
allMatches(String input, {int start = 0, bool overlapping = false}) → Iterable<T>

Available on Parser<T>, provided by the MatchesParserExtension extension

Returns a lazy iterable over all non-overlapping successful parse results of type T over the provided input.
and() → Parser<R>

Available on Parser<R>, provided by the AndParserExtension extension

Returns a parser (logical and-predicate) that succeeds whenever the receiver does, but never consumes input.
callCC<S>(ContinuationHandler<R, S> handler) → Parser<S>

Available on Parser<R>, provided by the ContinuationParserExtension extension

Returns a parser that when activated captures a continuation function and passes it together with the current context into the handler.
cast<S>() → Parser<S>

Available on Parser<R>, provided by the CastParserExtension extension

Returns a parser that casts itself to Parser<R>.
castList<S>() → Parser<List<S>>

Available on Parser<R>, provided by the CastListParserExtension extension

Returns a parser that casts itself to Parser<List<R>>.
constant<S>(S value) → Parser<S>

Available on Parser<R>, provided by the ConstantParserExtension extension

Returns a parser that returns a constant value.
copy() → SettableParser<R>
Creates a shallow copy of this parser.
override
end({String message = 'end of input expected'}) → Parser<R>

Available on Parser<R>, provided by the EndOfInputParserExtension extension

Returns a parser that succeeds only if the receiver consumes the complete input, otherwise return a failure with the optional message.
fastParseOn(String buffer, int position) → int
Parses buffer starting at position without allocating a Result.
override
flatten({String? message}) → Parser<String>

Available on Parser, provided by the FlattenParserExtension extension

Returns a parser that discards the result of the receiver and answers the sub-string its delegate consumes.
hasEqualChildren(covariant Parser other, Set<Parser> seen) → bool
Compares the children of this parser with other.
inherited
hasEqualProperties(covariant Parser other) → bool
Compares the properties of this parser with other.
inherited
isEqualTo(Parser other, [Set<Parser>? seen]) → bool
Tests if this parser is structurally equal to other.
inherited
labeled(String label) → LabeledParser<R>

Available on Parser<R>, provided by the LabelParserExtension extension

Returns a parser that simply defers to its delegate, but that has a label for debugging purposes.
map<S>(Callback<R, S> callback, {bool hasSideEffects = false}) → Parser<S>

Available on Parser<R>, provided by the MapParserExtension extension

Returns a parser that evaluates a callback as the production action on success of the receiver.
map2<R>(R callback(T1, T2), {bool hasSideEffects = false}) → Parser<R>

Available on Parser<(T1, T2)>, provided by the RecordParserExtension2 extension

Maps a parsed Record to R using the provided callback.
map3<R>(R callback(T1, T2, T3), {bool hasSideEffects = false}) → Parser<R>

Available on Parser<(T1, T2, T3)>, provided by the RecordParserExtension3 extension

Maps a parsed Record to R using the provided callback.
map4<R>(R callback(T1, T2, T3, T4), {bool hasSideEffects = false}) → Parser<R>

Available on Parser<(T1, T2, T3, T4)>, provided by the RecordParserExtension4 extension

Maps a parsed Record to R using the provided callback.
map5<R>(R callback(T1, T2, T3, T4, T5), {bool hasSideEffects = false}) → Parser<R>

Available on Parser<(T1, T2, T3, T4, T5)>, provided by the RecordParserExtension5 extension

Maps a parsed Record to R using the provided callback.
map6<R>(R callback(T1, T2, T3, T4, T5, T6), {bool hasSideEffects = false}) → Parser<R>

Available on Parser<(T1, T2, T3, T4, T5, T6)>, provided by the RecordParserExtension6 extension

Maps a parsed Record to R using the provided callback.
map7<R>(R callback(T1, T2, T3, T4, T5, T6, T7), {bool hasSideEffects = false}) → Parser<R>

Available on Parser<(T1, T2, T3, T4, T5, T6, T7)>, provided by the RecordParserExtension7 extension

Maps a parsed Record to R using the provided callback.
map8<R>(R callback(T1, T2, T3, T4, T5, T6, T7, T8), {bool hasSideEffects = false}) → Parser<R>

Available on Parser<(T1, T2, T3, T4, T5, T6, T7, T8)>, provided by the RecordParserExtension8 extension

Maps a parsed Record to R using the provided callback.
map9<R>(R callback(T1, T2, T3, T4, T5, T6, T7, T8, T9), {bool hasSideEffects = false}) → Parser<R>

Available on Parser<(T1, T2, T3, T4, T5, T6, T7, T8, T9)>, provided by the RecordParserExtension9 extension

Maps a parsed Record to R using the provided callback.
neg({String message = 'input not expected'}) → Parser<String>

Available on Parser<R>, provided by the NotParserExtension extension

Returns a parser that consumes any input token (character), but the receiver.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not({String message = 'success not expected'}) → Parser<Failure>

Available on Parser<R>, provided by the NotParserExtension extension

Returns a parser (logical not-predicate) that succeeds with the Failure whenever the receiver fails, but never consumes input.
optional() → Parser<R?>

Available on Parser<R>, provided by the OptionalParserExtension extension

Returns a new parser that accepts the receiver, if possible.
optionalWith(R value) → Parser<R>

Available on Parser<R>, provided by the OptionalParserExtension extension

Returns a new parser that accepts the receiver, if possible.
or(Parser other, {FailureJoiner? failureJoiner}) → ChoiceParser

Available on Parser, provided by the ChoiceParserExtension extension

Returns a parser that accepts the receiver or other (ordered choice).
parse(String input, {int start = 0}) → Result<R>
Parses the input and returns the parse result.
inherited
parseOn(Context context) → Result<R>
Parses the given context.
override
permute(List<int> indexes) → Parser<List<R>>

Available on Parser<List<R>>, provided by the PermuteParserExtension extension

Returns a parser that transforms a successful parse result by returning the permuted elements at indexes of a list.
pick(int index) → Parser<R>

Available on Parser<List<R>>, provided by the PickParserExtension extension

Returns a parser that transforms a successful parse result by returning the element at index of a list.
plus() → Parser<List<R>>

Available on Parser<R>, provided by the PossessiveRepeatingParserExtension extension

Returns a parser that accepts the receiver one or more times.
plusGreedy(Parser<void> limit) → Parser<List<R>>

Available on Parser<R>, provided by the GreedyRepeatingParserExtension extension

Returns a parser that parses the receiver one or more times until it reaches limit.
plusLazy(Parser<void> limit) → Parser<List<R>>

Available on Parser<R>, provided by the LazyRepeatingParserExtension extension

Returns a parser that parses the receiver one or more times until it reaches a limit.
plusSeparated<S>(Parser<S> separator) → Parser<SeparatedList<R, S>>

Available on Parser<R>, provided by the SeparatedRepeatingParserExtension extension

Returns a parser that consumes the receiver one or more times separated by the separator parser.
plusString({String? message}) → Parser<String>

Available on Parser<String>, provided by the RepeatingCharacterParserExtension extension

Returns a parser that accepts the receiver one or more times.
repeat(int min, [int? max]) → Parser<List<R>>

Available on Parser<R>, provided by the PossessiveRepeatingParserExtension extension

Returns a parser that accepts the receiver between min and max times.
repeatGreedy(Parser<void> limit, int min, int max) → Parser<List<R>>

Available on Parser<R>, provided by the GreedyRepeatingParserExtension extension

Returns a parser that parses the receiver at least min and at most max times until it reaches a limit.
repeatLazy(Parser<void> limit, int min, int max) → Parser<List<R>>

Available on Parser<R>, provided by the LazyRepeatingParserExtension extension

Returns a parser that parses the receiver at least min and at most max times until it reaches a limit.
repeatSeparated<S>(Parser<S> separator, int min, int max) → Parser<SeparatedList<R, S>>

Available on Parser<R>, provided by the SeparatedRepeatingParserExtension extension

Returns a parser that consumes the receiver between min and max times separated by the separator parser.
repeatString(int min, int max, {String? message}) → Parser<String>

Available on Parser<String>, provided by the RepeatingCharacterParserExtension extension

Returns a parser that accepts the receiver between min and max times.
replace(Parser source, Parser target) → void
Replaces source with target in this parser.
inherited
resolve() → Parser<R>
Resolves this parser with another one of the same type.
override
seq(Parser other) → Parser<List>

Available on Parser<R1>, provided by the SequenceParserExtension extension

Returns a parser that accepts the receiver followed by other.
set(Parser<R> parser) → void
Sets the receiver to delegate to parser.
settable() → SettableParser<R>

Available on Parser<R>, provided by the SettableParserExtension extension

Returns a parser that points to the receiver, but can be changed to point to something else at a later point in time.
skip({Parser<void>? before, Parser<void>? after}) → Parser<R>

Available on Parser<R>, provided by the SkipParserExtension extension

Returns a parser that consumes input before and after the receiver, but discards the parse results of before and after and only returns the result of the receiver.
star() → Parser<List<R>>

Available on Parser<R>, provided by the PossessiveRepeatingParserExtension extension

Returns a parser that accepts the receiver zero or more times.
starGreedy(Parser<void> limit) → Parser<List<R>>

Available on Parser<R>, provided by the GreedyRepeatingParserExtension extension

Returns a parser that parses the receiver zero or more times until it reaches a limit.
starLazy(Parser<void> limit) → Parser<List<R>>

Available on Parser<R>, provided by the LazyRepeatingParserExtension extension

Returns a parser that parses the receiver zero or more times until it reaches a limit.
starSeparated<S>(Parser<S> separator) → Parser<SeparatedList<R, S>>

Available on Parser<R>, provided by the SeparatedRepeatingParserExtension extension

Returns a parser that consumes the receiver zero or more times separated by the separator parser.
starString({String? message}) → Parser<String>

Available on Parser<String>, provided by the RepeatingCharacterParserExtension extension

Returns a parser that accepts the receiver zero or more times.
then<R2>(Parser<R2> other) → SequenceParser2<R1, R2>

Available on Parser<R1>, provided by the SequenceParserExtension extension

Returns a parser that sequences the receiver and other, returning their results as a typed 2-element Record.
times(int count) → Parser<List<R>>

Available on Parser<R>, provided by the PossessiveRepeatingParserExtension extension

Returns a parser that accepts the receiver exactly count times.
timesSeparated<S>(Parser<S> separator, int count) → Parser<SeparatedList<R, S>>

Available on Parser<R>, provided by the SeparatedRepeatingParserExtension extension

Returns a parser that consumes the receiver count times separated by the separator parser.
timesString(int count, {String? message}) → Parser<String>

Available on Parser<String>, provided by the RepeatingCharacterParserExtension extension

Returns a parser that accepts the receiver exactly count times.
token() → Parser<Token<R>>

Available on Parser<R>, provided by the TokenParserExtension extension

Returns a parser that returns a Token.
toPattern() → Pattern

Available on Parser<R>, provided by the PatternParserExtension extension

Converts this Parser into a Pattern for basic searches within strings.
toString() → String
A string representation of this object.
inherited
trim([Parser<void>? left, Parser<void>? right]) → Parser<R>

Available on Parser<R>, provided by the TrimmingParserExtension extension

Returns a parser that consumes input before and after the receiver, discards the excess input and only returns the result of the receiver.
where(Predicate<R> predicate, {String? message, FailureFactory<R>? factory}) → Parser<R>

Available on Parser<R>, provided by the WhereParserExtension extension

Returns a parser that evaluates the predicate with the successful parse result.

Operators

operator &(Parser other) → Parser<List>

Available on Parser<R1>, provided by the SequenceParserExtension extension

Combines this parser and other into a sequence, equivalent to calling seq.
operator ==(Object other) → bool
The equality operator.
inherited
operator |(Parser other) → ChoiceParser

Available on Parser, provided by the ChoiceParserExtension extension

Combines this parser and other into a choice, equivalent to calling or.