operator & method
Combines this parser and other into a sequence, equivalent to calling seq.
Combines the receiver and other into a sequential parser producing
a List<dynamic>.
final parser = letter() & digit().map(int.parse) & letter();
parser.parse('a1b'); // Success: ['a', 1, 'b']
Implementation
@useResult
Parser<List<dynamic>> operator &(Parser other) => seq(other);